@@ -14,6 +14,10 @@
 #include <array>
 #include <cassert>
 
+// std::array is explicitly allowed to be initialized with A a = { init-list };.
+// Disable the missing braces warning for this reason.
+#include "disable_missing_braces_warning.h"
+
 int main()
 {
     {
@@ -27,6 +31,4 @@ int main()
         *i = 5.5;
         assert(c[0] == 5.5);
     }
-    {
-    }
 }
