@@ -31,7 +31,7 @@ int main()
         C c3(std::begin(t3), std::end(t3));
         assert(c1 == c3);
     }
-#if __cplusplus >= 201103L
+#if TEST_STD_VER >= 11
     {
         typedef int T;
         typedef std::forward_list<T, min_allocator<T>> C;
